==> haskell-x11-1.10.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 X11
version:              1.10.3
visibility:           public
id:                   X11-1.10.3-8NdPo2dy5eHGXd7RnXiWFu
key:                  X11-1.10.3-8NdPo2dy5eHGXd7RnXiWFu
license:              BSD-3-Clause
copyright:
    Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007,
    Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.

maintainer:           Daniel Wagner <daniel@wagner-home.com>
homepage:             https://github.com/xmonad/X11
synopsis:             A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library. The binding is a direct
    translation of the C binding; for documentation of these calls, refer
    to \"The Xlib Programming Manual\", available online at
    <http://tronche.com/gui/x/xlib/>.

category:             Graphics
abi:                  25d478b94ba91d635d32228f4b06bdd5
exposed:              True
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr

hidden-modules:       Graphics.X11.Xlib.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/X11-1.10.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/X11-1.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x11
hs-libraries:         HSX11-1.10.3-8NdPo2dy5eHGXd7RnXiWFu
extra-libraries:      Xss Xinerama Xext X11 Xrandr Xext
include-dirs:         /usr/lib/ghc-9.2.8/site-local/X11-1.10.3/include
includes:             HsXlib.h HsAllKeysyms.h
depends:
    base-4.16.4.0 data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp

ld-options:
    "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now" -flto=auto

haddock-interfaces:   /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html:         /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-1.10.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 X11
version:              1.10.3
visibility:           public
id:                   X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
key:                  X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
license:              BSD-3-Clause
copyright:
    Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007,
    Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.

maintainer:           Daniel Wagner <daniel@wagner-home.com>
homepage:             https://github.com/xmonad/X11
synopsis:             A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library. The binding is a direct
    translation of the C binding; for documentation of these calls, refer
    to \"The Xlib Programming Manual\", available online at
    <http://tronche.com/gui/x/xlib/>.

category:             Graphics
abi:                  99753da9f64fd5800d4dda32d3d1e6a6
exposed:              True
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr

hidden-modules:       Graphics.X11.Xlib.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/X11-1.10.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/X11-1.10.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/X11-1.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x11
hs-libraries:         HSX11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
extra-libraries:      Xss Xinerama Xext X11 Xrandr Xext
include-dirs:         /usr/lib/ghc-9.4.8/site-local/X11-1.10.3/include
includes:             HsXlib.h HsAllKeysyms.h
depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc

ld-options:
    "-Wl,-O1" "-Wl,--sort-common" "-Wl,--as-needed" "-Wl,-z,relro"
    "-Wl,-z,now" -flto=auto

haddock-interfaces:   /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html:         /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
